@@ -12,7 +12,7 @@ import (
 )
 
 const (
-	version = "0.22.0"
+	version = "0.22.2"
 )
 
 func main() {
@@ -79,6 +79,6 @@ func main() {
 	}()
 	sig := <-sigChan
 	log.Infof("Caught signal %v", sig)
-	d.BlockUntilStateSynched()
+	d.Quit()
 	os.Exit(0)
 }
